@@ -2,10 +2,14 @@ test_generate_concept_cohort_set <- function(con, cdm_schema, write_schema) {
   skip_if_not_installed("CirceR")
   # withr::local_options("CDMConnector.cohort_as_temp" = FALSE) # temp cohort tables are not implemented yet
   cdm <- cdm_from_con(
-    con = con, cdm_name = "eunomia", cdm_schema = cdm_schema,
-    write_schema = write_schema
+    con = con, cdm_name = "eunomia",
+    cdm_schema = cdm_schema,
+    write_schema = write_schema,
+    .soft_validation = (dbms(con) == "sql server")
   )
 
+  # The sql server test database is missing columns on visit_detail and note tables.
+
   # check that we have records
   cdm$condition_occurrence %>%
     dplyr::filter(condition_concept_id == 192671) %>%
