@@ -1,6 +1,9 @@
 test_new_generated_cohort_set <- function(con, cdm_schema, write_schema) {
 
-  cdm <- cdm_from_con(con, cdm_schema = cdm_schema, write_schema = write_schema)
+  cdm <- cdm_from_con(
+    con = con, cdm_name = "eunomia", cdm_schema = cdm_schema,
+    write_schema = write_schema
+  )
 
   x <- cdm$condition_occurrence %>%
     dplyr::filter(condition_concept_id == 4112343) %>%
@@ -54,33 +57,28 @@ test_new_generated_cohort_set <- function(con, cdm_schema, write_schema) {
 
 
   cdm$new_cohort <- x %>%
-    computeQuery(
-      name = "new_cohort",
-      temporary = FALSE,
-      schema = attr(cdm, "write_schema"),
-      overwrite = TRUE)
+    compute(name = "new_cohort", temporary = FALSE, overwrite = TRUE)
 
-  cdm$new_cohort <- newGeneratedCohortSet(
+  cdm$new_cohort <- omopgenerics::newCohortTable(
       cdm$new_cohort,
       cohortSetRef = dplyr::tibble(
         cohort_definition_id = 1,
         cohort_name = "pharyngitis"
-      ),
-      overwrite = TRUE)
+      ))
 
   expect_s3_class(cdm$new_cohort, "GeneratedCohortSet")
 
   expect_true(all(
-    c("cdm_reference", "cohort_set", "cohort_attrition", "cohort_count", "tbl_name") %in% names(attributes(cdm$new_cohort))
+    c("cdm_reference", "cohort_set", "cohort_attrition", "tbl_name") %in% names(attributes(cdm$new_cohort))
   ))
 
   expect_true(attr(cdm$new_cohort, "tbl_name") == "new_cohort")
 
   # remove the cohort tables.
   if ("prefix" %in% names(write_schema)) {
-    drop_table(cdm, dplyr::starts_with(write_schema["prefix"]))
+    dropTable(cdm, dplyr::starts_with(write_schema["prefix"]))
   } else {
-    drop_table(cdm, dplyr::starts_with("new_cohort"))
+    dropTable(cdm, dplyr::starts_with("new_cohort"))
   }
 
 }
@@ -103,8 +101,10 @@ for (dbtype in dbToTest) {
 
 test_that("error in newGeneratedCohortSet if cohort_ref has not been computed", {
   skip_if_not_installed("duckdb")
-  con <- DBI::dbConnect(duckdb::duckdb(), eunomia_dir())
-  cdm <- cdm_from_con(con, cdm_schema = "main", write_schema = "main")
+  con <- DBI::dbConnect(duckdb::duckdb(dbdir = eunomia_dir()))
+  cdm <- cdm_from_con(
+    con = con, cdm_name = "eunomia", cdm_schema = "main", write_schema = "main"
+  )
 
   cohort_ref <- cdm$condition_occurrence %>%
     dplyr::filter(condition_concept_id == 192671) %>%
@@ -117,7 +117,7 @@ test_that("error in newGeneratedCohortSet if cohort_ref has not been computed",
                   "cohort_start_date" = "condition_start_date",
                   "cohort_end_date" = "condition_end_date")
 
-  expect_error(newGeneratedCohortSet(cohort_ref))
+  expect_error(omopgenerics::newCohortTable(cohort_ref))
 
   DBI::dbDisconnect(con, shutdown = TRUE)
 })
@@ -126,8 +126,10 @@ test_that("no error if cohort is empty", {
   skip_if_not_installed("CirceR")
   skip_if_not_installed("duckdb")
   # if an empty cohort is passed return an empty GeneratedCohortSet object
-  con <- DBI::dbConnect(duckdb::duckdb(), eunomia_dir())
-  cdm <- cdm_from_con(con, cdm_schema = "main", write_schema = "main")
+  con <- DBI::dbConnect(duckdb::duckdb(dbdir = eunomia_dir()))
+  cdm <- cdm_from_con(
+    con = con, cdm_name = "eunomia", cdm_schema = "main", write_schema = "main"
+  )
 
   inst_dir <- system.file(package = "CDMConnector", mustWork = TRUE)
 
@@ -141,25 +143,30 @@ test_that("no error if cohort is empty", {
                            overwrite = TRUE,
                            computeAttrition = TRUE)
 
-  expect_true("GeneratedCohortSet" %in% class(cdm$cohorts2))
+  expect_true("cohort_table" %in% class(cdm$cohorts2))
+
+  # cdm$cohort_3 <- cdm$cohorts2 %>%
+  #   dplyr::filter(cohort_start_date > "2030-01-01") %>%
+  #   computeQuery(name = "cohorts_3", temporary = FALSE, schema = cdmWriteSchema(cdm))
 
   cdm$cohort_3 <- cdm$cohorts2 %>%
     dplyr::filter(cohort_start_date > "2030-01-01") %>%
-    compute_query()
+    compute(name = "cohort_3", temporary = FALSE) %>%
+    newCohortTable()
 
-  cdm$cohort_3a <-  cdm$cohort_3 %>%
-    newGeneratedCohortSet(overwrite = TRUE)
-  expect_true("GeneratedCohortSet" %in% class(cdm$cohort_3a))
+  expect_true("cohort_table" %in% class(cdm$cohort_3))
   # we won't have cohort set or cohort count as we didn't provide the cohort set ref
-  expect_true(nrow(cohort_set(cdm$cohort_3a)) == 0)
-  expect_true(nrow(cohort_count(cdm$cohort_3a)) == 0)
+  # expect_true(nrow(cohort_set(cdm$cohort_3)) == 0)
+  # expect_true(nrow(cohort_count(cdm$cohort_3)) == 0)
 
-  c_Ref<- cohort_set(cdm$cohort_3)
-  cdm$cohort_3b <-  cdm$cohort_3 %>%
-    newGeneratedCohortSet(cohortSetRef = c_Ref,
-                            overwrite = TRUE)
-  expect_true("GeneratedCohortSet" %in% class(cdm$cohort_3b))
-  expect_false(nrow(cohort_set(cdm$cohort_3b)) == 0)
+  c_Ref<- settings(cdm$cohort_3)
+
+  cdm$cohort_3b <- cdm$cohort_3 %>%
+    dplyr::compute(name = "cohort_3b", temporary = FALSE) |>
+    omopgenerics::newCohortTable(cohortSetRef = c_Ref)
+
+  expect_true("cohort_table" %in% class(cdm$cohort_3b))
+  expect_false(nrow(settings(cdm$cohort_3b)) == 0)
   expect_false(nrow(cohort_count(cdm$cohort_3b)) == 0)
 
   cdm_disconnect(cdm)
@@ -171,8 +178,10 @@ test_that("newGeneratedCohortSet handles empty cohort tables", {
   skip_if_not_installed("duckdb")
   skip_if_not_installed("CirceR")
 
-  con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
-  cdm <- cdm_from_con(con, cdm_schema = "main", write_schema = "main")
+  con <- DBI::dbConnect(duckdb::duckdb(dbdir = eunomia_dir()))
+  cdm <- cdm_from_con(
+    con = con, cdm_name = "eunomia", cdm_schema = "main", write_schema = "main"
+  )
 
   cohortSet <- readCohortSet(system.file("cohorts2",
                                          package = "CDMConnector",
@@ -186,10 +195,11 @@ test_that("newGeneratedCohortSet handles empty cohort tables", {
   expect_no_error({
     cdm$cohort_3 <- cdm$cohorts2 %>%
       dplyr::filter(cohort_start_date > "2099-01-01") %>%
-      compute_query() %>%
-      newGeneratedCohortSet()
+      compute(name = "cohort_3", temporary = FALSE) %>%
+      omopgenerics::newCohortTable()
   })
 
   expect_equal(nrow(dplyr::collect(cdm$cohort_3)), 0)
   DBI::dbDisconnect(con, shutdown = T)
 })
+
